# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: policy.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cpolicy.proto\x12\x0fomium.policy.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\x13\x43reatePolicyRequest\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12+\n\ndefinition\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x12\n\ncreated_by\x18\x06 \x01(\t\"g\n\x14\x43reatePolicyResponse\x12\'\n\x06policy\x18\x01 \x01(\x0b\x32\x17.omium.policy.v1.Policy\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"%\n\x10GetPolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\"d\n\x11GetPolicyResponse\x12\'\n\x06policy\x18\x01 \x01(\x0b\x32\x17.omium.policy.v1.Policy\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"G\n\x13ListPoliciesRequest\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\"i\n\x14ListPoliciesResponse\x12)\n\x08policies\x18\x01 \x03(\x0b\x32\x17.omium.policy.v1.Policy\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"\x89\x01\n\x13UpdatePolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12+\n\ndefinition\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\"g\n\x14UpdatePolicyResponse\x12\'\n\x06policy\x18\x01 \x01(\x0b\x32\x17.omium.policy.v1.Policy\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"(\n\x13\x44\x65letePolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\">\n\x14\x44\x65letePolicyResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"^\n\x15\x45valuatePolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x32\n\x11\x65xecution_context\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"y\n\x16\x45valuatePolicyResponse\x12\x37\n\x06result\x18\x01 \x01(\x0b\x32\'.omium.policy.v1.PolicyEvaluationResult\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"\x8d\x02\n\x06Policy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttenant_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\x05\x12+\n\ndefinition\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\n \x01(\t\"\xb5\x01\n\x16PolicyEvaluationResult\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x11\n\ttriggered\x18\x02 \x01(\x08\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x31\n\x07\x61\x63tions\x18\x04 \x01(\x0b\x32 .omium.policy.v1.RecoveryActions\x12\x32\n\x0cretry_policy\x18\x05 \x01(\x0b\x32\x1c.omium.policy.v1.RetryPolicy\"\x9c\x01\n\x0fRecoveryActions\x12#\n\x1brollback_to_last_checkpoint\x18\x01 \x01(\x08\x12\x18\n\x10pause_and_notify\x18\x02 \x01(\x08\x12\x1a\n\x12\x61wait_human_review\x18\x03 \x01(\x08\x12\x15\n\rallowed_edits\x18\x04 \x03(\t\x12\x17\n\x0f\x66orbidden_edits\x18\x05 \x03(\t\"F\n\x0bRetryPolicy\x12\x13\n\x0bmax_retries\x18\x01 \x01(\x05\x12\x0f\n\x07\x62\x61\x63koff\x18\x02 \x01(\t\x12\x11\n\tcondition\x18\x03 \x01(\t2\xba\x04\n\rPolicyService\x12[\n\x0c\x43reatePolicy\x12$.omium.policy.v1.CreatePolicyRequest\x1a%.omium.policy.v1.CreatePolicyResponse\x12R\n\tGetPolicy\x12!.omium.policy.v1.GetPolicyRequest\x1a\".omium.policy.v1.GetPolicyResponse\x12[\n\x0cListPolicies\x12$.omium.policy.v1.ListPoliciesRequest\x1a%.omium.policy.v1.ListPoliciesResponse\x12[\n\x0cUpdatePolicy\x12$.omium.policy.v1.UpdatePolicyRequest\x1a%.omium.policy.v1.UpdatePolicyResponse\x12[\n\x0c\x44\x65letePolicy\x12$.omium.policy.v1.DeletePolicyRequest\x1a%.omium.policy.v1.DeletePolicyResponse\x12\x61\n\x0e\x45valuatePolicy\x12&.omium.policy.v1.EvaluatePolicyRequest\x1a\'.omium.policy.v1.EvaluatePolicyResponseBBZ@github.com/omium/policy-engine/internal/proto/generated;policypbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z@github.com/omium/policy-engine/internal/proto/generated;policypb'
  _globals['_CREATEPOLICYREQUEST']._serialized_start=97
  _globals['_CREATEPOLICYREQUEST']._serialized_end=254
  _globals['_CREATEPOLICYRESPONSE']._serialized_start=256
  _globals['_CREATEPOLICYRESPONSE']._serialized_end=359
  _globals['_GETPOLICYREQUEST']._serialized_start=361
  _globals['_GETPOLICYREQUEST']._serialized_end=398
  _globals['_GETPOLICYRESPONSE']._serialized_start=400
  _globals['_GETPOLICYRESPONSE']._serialized_end=500
  _globals['_LISTPOLICIESREQUEST']._serialized_start=502
  _globals['_LISTPOLICIESREQUEST']._serialized_end=573
  _globals['_LISTPOLICIESRESPONSE']._serialized_start=575
  _globals['_LISTPOLICIESRESPONSE']._serialized_end=680
  _globals['_UPDATEPOLICYREQUEST']._serialized_start=683
  _globals['_UPDATEPOLICYREQUEST']._serialized_end=820
  _globals['_UPDATEPOLICYRESPONSE']._serialized_start=822
  _globals['_UPDATEPOLICYRESPONSE']._serialized_end=925
  _globals['_DELETEPOLICYREQUEST']._serialized_start=927
  _globals['_DELETEPOLICYREQUEST']._serialized_end=967
  _globals['_DELETEPOLICYRESPONSE']._serialized_start=969
  _globals['_DELETEPOLICYRESPONSE']._serialized_end=1031
  _globals['_EVALUATEPOLICYREQUEST']._serialized_start=1033
  _globals['_EVALUATEPOLICYREQUEST']._serialized_end=1127
  _globals['_EVALUATEPOLICYRESPONSE']._serialized_start=1129
  _globals['_EVALUATEPOLICYRESPONSE']._serialized_end=1250
  _globals['_POLICY']._serialized_start=1253
  _globals['_POLICY']._serialized_end=1522
  _globals['_POLICYEVALUATIONRESULT']._serialized_start=1525
  _globals['_POLICYEVALUATIONRESULT']._serialized_end=1706
  _globals['_RECOVERYACTIONS']._serialized_start=1709
  _globals['_RECOVERYACTIONS']._serialized_end=1865
  _globals['_RETRYPOLICY']._serialized_start=1867
  _globals['_RETRYPOLICY']._serialized_end=1937
  _globals['_POLICYSERVICE']._serialized_start=1940
  _globals['_POLICYSERVICE']._serialized_end=2510
# @@protoc_insertion_point(module_scope)
